## Version 0.12.2

This minor release includes a simplification of the .gitignore file creation process within the ensure_db_in_gitignore function, enhancing maintainability and clarity.

### New Features

- Simplified the creation of the .gitignore file in the .llamabot directory to only ignore all files within it, removing unnecessary comments and exceptions. (f7bfe9) (Eric Ma)

### Bug Fixes

### Deprecations

Please note that this release does not include any new bug fixes or deprecations.
